/*
Example for Brushless_2 Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration AVR :
    
    MCU             : ATMEGA32
    Dev. Board      : EasyAVR v7 
    SW              : mikroC PRO for AVR v7.0.0

Description :

    This simple example demonstrates driving the motor with Brushless 2 click, 
    direction of motor is controled via MOTOR_DIR_PIN and speed is regulated with PWM.
    Board specific: Button press level PB to VCC, and PORTA pull down RB0 and RB1, 
    speed is controlled by pressing RB0 and direction is changed by pressing RB1.

*/
#include "stdint.h"

sbit MOTOR_DIR_PIN at PORTA6_bit;
sbit MOTOR_DIR_PIN_Direction at DDA6_bit;

uint8_t const maxPwmDuty = 255;
uint8_t currentDuty = 20 ;
uint8_t oldstate = 0;

void systemInit()
{
    PWM16bit_Init(_PWM16_PHASE_CORRECT_MODE_8BIT, _PWM16_PRESCALER_16bit_8, _PWM16_NON_INVERTED, 255, 1);  // PWM Init
    PWM16bit_Start(_TIMER1);
    PWM16bit_Change_Duty(currentDuty, _TIMER1_CH_B);
    MOTOR_DIR_PIN_Direction = 1;
}

void Brushless_2_Init()
{
    DDB0_bit = 0;
    DDD4_bit = 1;
    MOTOR_DIR_PIN = 1;
}

void Brushless_2_Task()
{
    if (!Button(&PINB, 0, 1, 1))
    {
         currentDuty++;
         PWM16bit_Change_Duty(currentDuty, _TIMER1_CH_B);
        if (currentDuty > maxPwmDuty)      
            currentDuty = 0;              
        
    }
     
    if (Button(&PINB, 1, 1, 1)) 
    {                                               
        oldstate = 1;                              
    }
    if (oldstate && Button(&PINB, 1, 1, 0)) 
    {   
        MOTOR_DIR_PIN = ~MOTOR_DIR_PIN;                              
        oldstate = 0;   
    }

}

void main()
{
    systemInit();
    Brushless_2_Init();

    while( 1 )
    {
            Brushless_2_Task();
    }
}